==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_groundstation/paginator.py <==
"""
Type annotations for groundstation service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_groundstation.client import GroundStationClient
    from types_boto3_groundstation.paginator import (
        ListConfigsPaginator,
        ListContactsPaginator,
        ListDataflowEndpointGroupsPaginator,
        ListEphemeridesPaginator,
        ListGroundStationsPaginator,
        ListMissionProfilesPaginator,
        ListSatellitesPaginator,
    )

    session = Session()
    client: GroundStationClient = session.client("groundstation")

    list_configs_paginator: ListConfigsPaginator = client.get_paginator("list_configs")
    list_contacts_paginator: ListContactsPaginator = client.get_paginator("list_contacts")
    list_dataflow_endpoint_groups_paginator: ListDataflowEndpointGroupsPaginator = client.get_paginator("list_dataflow_endpoint_groups")
    list_ephemerides_paginator: ListEphemeridesPaginator = client.get_paginator("list_ephemerides")
    list_ground_stations_paginator: ListGroundStationsPaginator = client.get_paginator("list_ground_stations")
    list_mission_profiles_paginator: ListMissionProfilesPaginator = client.get_paginator("list_mission_profiles")
    list_satellites_paginator: ListSatellitesPaginator = client.get_paginator("list_satellites")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListConfigsRequestListConfigsPaginateTypeDef,
    ListConfigsResponseTypeDef,
    ListContactsRequestListContactsPaginateTypeDef,
    ListContactsResponseTypeDef,
    ListDataflowEndpointGroupsRequestListDataflowEndpointGroupsPaginateTypeDef,
    ListDataflowEndpointGroupsResponseTypeDef,
    ListEphemeridesRequestListEphemeridesPaginateTypeDef,
    ListEphemeridesResponseTypeDef,
    ListGroundStationsRequestListGroundStationsPaginateTypeDef,
    ListGroundStationsResponseTypeDef,
    ListMissionProfilesRequestListMissionProfilesPaginateTypeDef,
    ListMissionProfilesResponseTypeDef,
    ListSatellitesRequestListSatellitesPaginateTypeDef,
    ListSatellitesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListConfigsPaginator",
    "ListContactsPaginator",
    "ListDataflowEndpointGroupsPaginator",
    "ListEphemeridesPaginator",
    "ListGroundStationsPaginator",
    "ListMissionProfilesPaginator",
    "ListSatellitesPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListConfigsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListConfigs.html#GroundStation.Paginator.ListConfigs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listconfigspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListConfigsRequestListConfigsPaginateTypeDef]
    ) -> _PageIterator[ListConfigsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListConfigs.html#GroundStation.Paginator.ListConfigs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listconfigspaginator)
        """


class ListContactsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListContacts.html#GroundStation.Paginator.ListContacts)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listcontactspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListContactsRequestListContactsPaginateTypeDef]
    ) -> _PageIterator[ListContactsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListContacts.html#GroundStation.Paginator.ListContacts.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listcontactspaginator)
        """


class ListDataflowEndpointGroupsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListDataflowEndpointGroups.html#GroundStation.Paginator.ListDataflowEndpointGroups)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listdataflowendpointgroupspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            ListDataflowEndpointGroupsRequestListDataflowEndpointGroupsPaginateTypeDef
        ],
    ) -> _PageIterator[ListDataflowEndpointGroupsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListDataflowEndpointGroups.html#GroundStation.Paginator.ListDataflowEndpointGroups.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listdataflowendpointgroupspaginator)
        """


class ListEphemeridesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListEphemerides.html#GroundStation.Paginator.ListEphemerides)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listephemeridespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListEphemeridesRequestListEphemeridesPaginateTypeDef]
    ) -> _PageIterator[ListEphemeridesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListEphemerides.html#GroundStation.Paginator.ListEphemerides.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listephemeridespaginator)
        """


class ListGroundStationsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListGroundStations.html#GroundStation.Paginator.ListGroundStations)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listgroundstationspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListGroundStationsRequestListGroundStationsPaginateTypeDef]
    ) -> _PageIterator[ListGroundStationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListGroundStations.html#GroundStation.Paginator.ListGroundStations.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listgroundstationspaginator)
        """


class ListMissionProfilesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListMissionProfiles.html#GroundStation.Paginator.ListMissionProfiles)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listmissionprofilespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListMissionProfilesRequestListMissionProfilesPaginateTypeDef]
    ) -> _PageIterator[ListMissionProfilesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListMissionProfiles.html#GroundStation.Paginator.ListMissionProfiles.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listmissionprofilespaginator)
        """


class ListSatellitesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListSatellites.html#GroundStation.Paginator.ListSatellites)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listsatellitespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListSatellitesRequestListSatellitesPaginateTypeDef]
    ) -> _PageIterator[ListSatellitesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListSatellites.html#GroundStation.Paginator.ListSatellites.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listsatellitespaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_groundstation/paginator.py <==
"""
Type annotations for groundstation service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_groundstation.client import GroundStationClient
    from types_boto3_groundstation.paginator import (
        ListConfigsPaginator,
        ListContactsPaginator,
        ListDataflowEndpointGroupsPaginator,
        ListEphemeridesPaginator,
        ListGroundStationsPaginator,
        ListMissionProfilesPaginator,
        ListSatellitesPaginator,
    )

    session = Session()
    client: GroundStationClient = session.client("groundstation")

    list_configs_paginator: ListConfigsPaginator = client.get_paginator("list_configs")
    list_contacts_paginator: ListContactsPaginator = client.get_paginator("list_contacts")
    list_dataflow_endpoint_groups_paginator: ListDataflowEndpointGroupsPaginator = client.get_paginator("list_dataflow_endpoint_groups")
    list_ephemerides_paginator: ListEphemeridesPaginator = client.get_paginator("list_ephemerides")
    list_ground_stations_paginator: ListGroundStationsPaginator = client.get_paginator("list_ground_stations")
    list_mission_profiles_paginator: ListMissionProfilesPaginator = client.get_paginator("list_mission_profiles")
    list_satellites_paginator: ListSatellitesPaginator = client.get_paginator("list_satellites")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListConfigsRequestPaginateTypeDef,
    ListConfigsResponseTypeDef,
    ListContactsRequestPaginateTypeDef,
    ListContactsResponseTypeDef,
    ListDataflowEndpointGroupsRequestPaginateTypeDef,
    ListDataflowEndpointGroupsResponseTypeDef,
    ListEphemeridesRequestPaginateTypeDef,
    ListEphemeridesResponseTypeDef,
    ListGroundStationsRequestPaginateTypeDef,
    ListGroundStationsResponseTypeDef,
    ListMissionProfilesRequestPaginateTypeDef,
    ListMissionProfilesResponseTypeDef,
    ListSatellitesRequestPaginateTypeDef,
    ListSatellitesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListConfigsPaginator",
    "ListContactsPaginator",
    "ListDataflowEndpointGroupsPaginator",
    "ListEphemeridesPaginator",
    "ListGroundStationsPaginator",
    "ListMissionProfilesPaginator",
    "ListSatellitesPaginator",
)


if TYPE_CHECKING:
    _ListConfigsPaginatorBase = Paginator[ListConfigsResponseTypeDef]
else:
    _ListConfigsPaginatorBase = Paginator  # type: ignore[assignment]


class ListConfigsPaginator(_ListConfigsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListConfigs.html#GroundStation.Paginator.ListConfigs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listconfigspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListConfigsRequestPaginateTypeDef]
    ) -> PageIterator[ListConfigsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListConfigs.html#GroundStation.Paginator.ListConfigs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listconfigspaginator)
        """


if TYPE_CHECKING:
    _ListContactsPaginatorBase = Paginator[ListContactsResponseTypeDef]
else:
    _ListContactsPaginatorBase = Paginator  # type: ignore[assignment]


class ListContactsPaginator(_ListContactsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListContacts.html#GroundStation.Paginator.ListContacts)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listcontactspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListContactsRequestPaginateTypeDef]
    ) -> PageIterator[ListContactsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListContacts.html#GroundStation.Paginator.ListContacts.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listcontactspaginator)
        """


if TYPE_CHECKING:
    _ListDataflowEndpointGroupsPaginatorBase = Paginator[ListDataflowEndpointGroupsResponseTypeDef]
else:
    _ListDataflowEndpointGroupsPaginatorBase = Paginator  # type: ignore[assignment]


class ListDataflowEndpointGroupsPaginator(_ListDataflowEndpointGroupsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListDataflowEndpointGroups.html#GroundStation.Paginator.ListDataflowEndpointGroups)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listdataflowendpointgroupspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDataflowEndpointGroupsRequestPaginateTypeDef]
    ) -> PageIterator[ListDataflowEndpointGroupsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListDataflowEndpointGroups.html#GroundStation.Paginator.ListDataflowEndpointGroups.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listdataflowendpointgroupspaginator)
        """


if TYPE_CHECKING:
    _ListEphemeridesPaginatorBase = Paginator[ListEphemeridesResponseTypeDef]
else:
    _ListEphemeridesPaginatorBase = Paginator  # type: ignore[assignment]


class ListEphemeridesPaginator(_ListEphemeridesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListEphemerides.html#GroundStation.Paginator.ListEphemerides)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listephemeridespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListEphemeridesRequestPaginateTypeDef]
    ) -> PageIterator[ListEphemeridesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListEphemerides.html#GroundStation.Paginator.ListEphemerides.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listephemeridespaginator)
        """


if TYPE_CHECKING:
    _ListGroundStationsPaginatorBase = Paginator[ListGroundStationsResponseTypeDef]
else:
    _ListGroundStationsPaginatorBase = Paginator  # type: ignore[assignment]


class ListGroundStationsPaginator(_ListGroundStationsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListGroundStations.html#GroundStation.Paginator.ListGroundStations)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listgroundstationspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListGroundStationsRequestPaginateTypeDef]
    ) -> PageIterator[ListGroundStationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListGroundStations.html#GroundStation.Paginator.ListGroundStations.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listgroundstationspaginator)
        """


if TYPE_CHECKING:
    _ListMissionProfilesPaginatorBase = Paginator[ListMissionProfilesResponseTypeDef]
else:
    _ListMissionProfilesPaginatorBase = Paginator  # type: ignore[assignment]


class ListMissionProfilesPaginator(_ListMissionProfilesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListMissionProfiles.html#GroundStation.Paginator.ListMissionProfiles)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listmissionprofilespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListMissionProfilesRequestPaginateTypeDef]
    ) -> PageIterator[ListMissionProfilesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListMissionProfiles.html#GroundStation.Paginator.ListMissionProfiles.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listmissionprofilespaginator)
        """


if TYPE_CHECKING:
    _ListSatellitesPaginatorBase = Paginator[ListSatellitesResponseTypeDef]
else:
    _ListSatellitesPaginatorBase = Paginator  # type: ignore[assignment]


class ListSatellitesPaginator(_ListSatellitesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListSatellites.html#GroundStation.Paginator.ListSatellites)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listsatellitespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListSatellitesRequestPaginateTypeDef]
    ) -> PageIterator[ListSatellitesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation/paginator/ListSatellites.html#GroundStation.Paginator.ListSatellites.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_groundstation/paginators/#listsatellitespaginator)
        """
